<%-- $Id: manage.jsp 8287 2024-10-28 06:59:41Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Johan Enell
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.AnnotationTypeCategory"
	import="net.sf.basedb.core.ItemSubtype"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.SessionControl.MainContext"
	import="net.sf.basedb.core.SyncFilter"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.PropertyFilter"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Enumeration"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.util.formatter.PropertyFilterFormatter"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="java.util.List"
	import="java.util.Date"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final Item itemType = Item.valueOf(request.getParameter("item_type"));
List<ItemContext> allContexts = sc.getNamedContexts(itemType);
int numListed = 0;
final DbControl dc = sc.newDbControl(":Manage presets "+itemType);
try
{
%>
<base:page type="popup" title="Manage presets">
<base:head scripts="table.js,~manage.js" styles="table.css,toolbar.css,filtertext.css" />
<base:body>
	<h1>Manage presets for <%=itemType%><base:help helpid="contexts.manage" /></h1>
	
	<div class="content">
	<%
	if (allContexts.size() == 0)
	{
		%>
		<table class="fullcc bg-filled-50 bottomborder"><tr><td>
			<b>You have not saved any presets for 
			<%=itemType%>
			</b>
		</td></tr></table>
		<%
	}
	else
	{
		%>
			<tbl:table 
				id="contexts"
				action="index.jsp"
				subclass="fulltable"
				stickyheaders="<%=null%>"
				>
				<tbl:hidden
					name="item_type"
					value="<%=itemType.name()%>"
				/>
				<tbl:columndef
					id="name"
					title="Name"
				/>
				<tbl:columndef
					id="subtype"
					title="Type"
				/>
				<tbl:columndef
					id="subcategory"
					title="Sub-category"
				/>
				<tbl:columndef
					id="filter"
					title="Filter"
				/>
				<tbl:columndef
					id="actions"
					title="&nbsp;"
				/>
				<tbl:toolbar
					visible="true"
					subclass="bottomborder bg-filled-50"
					style="height: 1.75em;"
					>
					<tbl:button 
						id="btnDeleteSelected"
						image="delete.png" 
						title="Delete&hellip;" 
						tooltip="Delete the selected items" 
					/>
				</tbl:toolbar>
				<tbl:data style="top: 1.75em;">
					<tbl:headers>
						<tbl:headerrow>
							<tbl:header 
								clazz="index"
								/>
							<tbl:header 
								clazz="check"
								visible="true"
								><base:icon 
									subclass="link table-check"
									image="check_uncheck.png" 
									tooltip="Toggle all (use CTRL, ALT or SHIFT to check/uncheck)" 
									data-form="contexts"
									style="align: left;"
								/>
							</tbl:header>
							<tbl:columnheaders />
						</tbl:headerrow>
					</tbl:headers>
					<tbl:rows>
					<%
					Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
					Formatter<PropertyFilter> filterFormatter = new PropertyFilterFormatter(dc, dateFormatter, true);
					for (ItemContext ctx : allContexts)
					{
						String name = ctx.getName();
						int id = ctx.getContextId();
						numListed++;
						ItemSubtype subtype = null;
						boolean readSubtype = true;
						try
						{
							subtype = ctx.getItemSubtype(dc);
						}
						catch (PermissionDeniedException ex)
						{
							readSubtype = false;
						}
						AnnotationTypeCategory category = null;
						boolean readCategory = true;
						try
						{
							category = ctx.getSubCategory(dc);
						}
						catch (PermissionDeniedException ex)
						{
							readCategory = false;
						}
						String filterString = "";
						StringBuilder sb = new StringBuilder();
						for (int filterRow = 0; filterRow < ctx.getFilterRows(); filterRow++)
						{
							sb.append(filterRow > 0 ? "\n<operator>OR</operator> " : "");
							List<String> filters = SyncFilter.getFormattedAndSortedFilters(ctx.getPropertyFilters(filterRow), filterFormatter);
							sb.append(Values.getString(filters, "\n   <operator>AND</operator> ", true));
						}
						filterString = sb.toString();
						%>
						<tbl:row>
							<tbl:header clazz="index"><%=numListed%></tbl:header>
							<tbl:header 
								clazz="check"
								><input 
									type="checkbox" 
									name="<%=id%>" 
									value="<%=id%>" 
									title="<%=HTML.encodeTags(name)%>" 
								></tbl:header>
							<tbl:cell column="name"><%=HTML.encodeTags(name)%></tbl:cell>
							<tbl:cell column="subtype"><%=Base.getEncodedName(subtype, !readSubtype) %></tbl:cell>
							<tbl:cell column="subcategory"><%=Base.getEncodedName(category, !readCategory)%></tbl:cell>
							<tbl:cell column="filter">
								<pre class="filtertext"><%=HTML.encodeTags(filterString, "value|name|operator|function|missing")%></pre>
							</tbl:cell>
							<tbl:cell column="actions">
								<span class="link auto-init" data-auto-init="load-context" data-context-id="<%=id%>"
									title="Load this preset">Load</span>
							</tbl:cell>
						</tbl:row>
						<%
					}
					if (numListed == 0)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer note">No presets were found</div>
						</tbl:panel>
						<%
					}
					%>
					</tbl:rows>
				</tbl:data>
			</tbl:table>
			<br>
			<%
		}
		%>
		</div>
	<base:buttongroup subclass="dialogbuttons">
		<base:button id="close" title="Close" />
	</base:buttongroup>

</base:body>
</base:page>
<%
}
finally
{
	if (dc != null) dc.close();
}
%>
